@@ -20,20 +20,18 @@
 #ifndef _MISC_H_
 #define _MISC_H_
 
-#include <glade/glade.h>
-
-#define GLADE_FILE_ABOUT PACKAGE_GLADE_FILE_DIR"/about.glade"
-#define GLADE_FILE_CONFIG PACKAGE_GLADE_FILE_DIR"/config.glade"
-#define GLADE_FILE_ABBREVIATION_ADD PACKAGE_GLADE_FILE_DIR"/abbr_add.glade"
-#define GLADE_FILE_CHOOSE PACKAGE_GLADE_FILE_DIR"/choose_file.glade"
-#define GLADE_FILE_ACTION_ADD PACKAGE_GLADE_FILE_DIR"/action_add.glade"
-#define GLADE_FILE_APP_ADD PACKAGE_GLADE_FILE_DIR"/app_add.glade"
-#define GLADE_FILE_RULE_ADD PACKAGE_GLADE_FILE_DIR"/rule_add.glade"
-#define GLADE_FILE_LIST PACKAGE_GLADE_FILE_DIR"/list.glade"
+#define UI_FILE_ABOUT PACKAGE_UI_FILE_DIR"/about.ui"
+#define UI_FILE_CONFIG PACKAGE_UI_FILE_DIR"/config.ui"
+#define UI_FILE_ABBREVIATION_ADD PACKAGE_UI_FILE_DIR"/abbr_add.ui"
+#define UI_FILE_CHOOSE PACKAGE_UI_FILE_DIR"/choose_file.ui"
+#define UI_FILE_ACTION_ADD PACKAGE_UI_FILE_DIR"/action_add.ui"
+#define UI_FILE_APP_ADD PACKAGE_UI_FILE_DIR"/app_add.ui"
+#define UI_FILE_RULE_ADD PACKAGE_UI_FILE_DIR"/rule_add.ui"
+#define UI_FILE_LIST PACKAGE_UI_FILE_DIR"/list.ui"
 
 char* xneur_get_file_content(const char *path);
-char* xneur_get_dict_path(GladeXML *gxml, int layout_no, const char *file_name);
-char* xneur_get_home_dict_path(GladeXML *gxml, int layout_no, const char *file_name);
+char* xneur_get_dict_path(GtkBuilder* builder, int layout_no, const char *file_name);
+char* xneur_get_home_dict_path(GtkBuilder* builder, int layout_no, const char *file_name);
 char* xneur_modifiers_to_string(unsigned int modifier);
 
 //void xneur_exit(void);
@@ -55,6 +53,9 @@ void xneur_rem_manual_app(GtkWidget *widget);
 void xneur_add_dont_send_keyrelease_app(void);
 void xneur_rem_dont_send_keyrelease_app(GtkWidget *widget);
 
+void xneur_add_delay_send_key_app(void);
+void xneur_rem_delay_send_key_app(GtkWidget *widget);
+
 void xneur_add_layout_app(void);
 void xneur_rem_layout_app(GtkWidget *widget);
 
@@ -74,8 +75,8 @@ void xneur_rem_autocompletion_exclude_app(GtkWidget *widget);
 void xneur_edit_action(GtkWidget *treeview);
 void xneur_clear_action(GtkWidget *treeview);
 
-void xneur_save_preference(GladeXML *gxml);
-void xneur_dontsave_preference(GladeXML *gxml);
+void xneur_save_preference(GtkBuilder* builder);
+void xneur_dontsave_preference(GtkBuilder* builder);
 
 void xneur_edit_sound(GtkWidget *treeview);
 
