@@ -40,6 +40,7 @@
 
 extern const char* arg_show_in_the_tray;
 extern const char* arg_rendering_engine;
+extern const char* arg_icons_directory;
 
 extern struct _xneur_config *xconfig;
 
@@ -53,6 +54,8 @@ Display *dpy = NULL;
 static int xneur_old_pid = -1;
 static int xneur_old_state = -1;
 static int xneur_old_group = -1;
+static char *xneur_old_symbol = NULL;
+
 static int force_update = FALSE;
 
 //#define ICON_SIZE 24
@@ -65,7 +68,7 @@ static void exec_user_action(char *cmd)
 	strcat(command, " 2> /dev/stdout");
 
 	FILE *fp = popen(command, "r");
-	free(command);
+	g_free(command);
 	if (fp == NULL)
 		return;
 
@@ -266,6 +269,7 @@ GdkPixbuf *text_to_gtk_pixbuf (gchar *text)
 static const char *get_tray_icon_name (char *name)
 {
 	const char * icon_name;
+	char *full_name = g_strdup_printf("%s-%s", PACKAGE, name);
 
 	if (strcasecmp(show_in_the_tray, "Icon") == 0)
 	{
@@ -273,22 +277,50 @@ static const char *get_tray_icon_name (char *name)
 		return icon_name;
 	}
 
+	if (strcasecmp(show_in_the_tray, "Directory") == 0)
+	{
+		gchar *string_value = NULL;
+		gxneur_config_read_str("icons_directory", &string_value);
+		if (string_value != NULL)
+		{
+			icon_name = g_strdup_printf ("%s%s%s.png", string_value,
+                                         G_DIR_SEPARATOR_S, name);
+			printf("Icons '%s'\n",icon_name);
+  			if (g_file_test (icon_name, G_FILE_TEST_EXISTS))
+				return icon_name;
+			icon_name = g_strdup_printf ("%s%s%s.png", string_value,
+                                         G_DIR_SEPARATOR_S, full_name);
+			if (g_file_test (icon_name, G_FILE_TEST_EXISTS))
+				return icon_name;
+			icon_name = g_strdup_printf ("%s%s%s.png", string_value,
+                                         G_DIR_SEPARATOR_S, PACKAGE);
+			if (g_file_test (icon_name, G_FILE_TEST_EXISTS))
+				return icon_name;
+		}
+		if (string_value != NULL)
+ 			g_free (string_value); 
+		icon_name = PACKAGE;
+		return icon_name;
+	}
+	
+	//return "/home/crew/develop/xneur-devel/gxneur/pixmaps/all pixmaps/switcher/gxneur.png";
+	
 	GtkIconTheme * theme = gtk_icon_theme_get_default( );
 
 	// if the tray's icon is a 48x48 file, use it;
 	// otherwise, use the fallback builtin icon 
-	if (!gtk_icon_theme_has_icon (theme, name))
+	if (!gtk_icon_theme_has_icon (theme, full_name))
 	{
 		icon_name = PACKAGE;
 	}
 	else
 	{
-		GtkIconInfo * icon_info = gtk_icon_theme_lookup_icon (theme, name, 48, GTK_ICON_LOOKUP_USE_BUILTIN);
+		GtkIconInfo * icon_info = gtk_icon_theme_lookup_icon (theme, full_name, 48, GTK_ICON_LOOKUP_USE_BUILTIN);
 		const gboolean icon_is_builtin = gtk_icon_info_get_filename (icon_info) == NULL;
 		gtk_icon_info_free (icon_info);
-		icon_name = icon_is_builtin ? PACKAGE : name;
+		icon_name = icon_is_builtin ? PACKAGE : full_name;
 	}
-
+	
 	return icon_name;
 }
 
@@ -302,7 +334,7 @@ gboolean clock_check(gpointer dummy)
 		xneur_old_pid = 1;
 	snprintf(ps_command, 1024, "ps -p %d | grep xneur", xneur_old_pid);
 	FILE *fp = popen(ps_command, "r");
-	free (ps_command);
+	g_free (ps_command);
 	if (fp != NULL)
 	{
 		char buffer[NAME_MAX];
@@ -314,40 +346,41 @@ gboolean clock_check(gpointer dummy)
 	if (xneur_pid == -1)
 		xneur_pid = xconfig->get_pid(xconfig);
 	
-	
 	int xneur_state = xconfig->manual_mode;
 	int xneur_group = get_active_kbd_group(dpy);
-
-	if (get_kbd_group_count(dpy) != xconfig->handle->total_languages)
+	char *xneur_symbol = get_active_kbd_symbol(dpy);
+	
+	/*if (get_kbd_group_count(dpy) != xconfig->handle->total_languages)
 	{
-		for (int i = 0; i < MAX_LAYOUTS; i++)
-		{
-			if (tray->images[i] != NULL)
-				g_free(tray->images[i]);
-		}
-
 		gtk_widget_destroy(GTK_WIDGET(tray->menu));
 		tray->menu = NULL;
 		
 		g_spawn_command_line_async(PACKAGE, NULL);
 		
 		gtk_main_quit();
-	}
+	}*/
 
 
 	if  (xneur_pid == xneur_old_pid &&
-	     xneur_state == xneur_old_state &&
-	    xneur_group == xneur_old_group &&
-	    force_update == FALSE)
+		xneur_state == xneur_old_state &&
+		xneur_group == xneur_old_group &&
+	    strcmp(xneur_old_symbol, xneur_symbol) == 0 && 
+		force_update == FALSE)
+	{
+		if (xneur_symbol != NULL)
+			g_free(xneur_symbol);
 		return TRUE;
-	
+	}
 	force_update = FALSE;
 
 	xneur_old_pid = xneur_pid;
 	xneur_old_state = xneur_state;
 	xneur_old_group = xneur_group;
-		
-	int lang = get_active_kbd_group(dpy);
+	if (xneur_old_symbol != NULL)
+	{
+		g_free(xneur_old_symbol);
+	}
+	xneur_old_symbol = xneur_symbol;
 	
 	gchar *hint;
 	gchar *status_text;
@@ -355,38 +388,38 @@ gboolean clock_check(gpointer dummy)
 	if (xneur_pid != -1)
 	{
 		//saturation = 1.0;
-		hint = g_strdup_printf("%s%s%s", _("X Neural Switcher running ("), xconfig->handle->languages[lang].dir, ")");
+		hint = g_strdup_printf("%s%s%s", _("X Neural Switcher running ("), xneur_symbol, ")");
 		status_text = g_strdup_printf("%s", _("Stop daemon"));
 	}
 	else
 	{
 		//saturation = 0.25;
-		hint = g_strdup_printf("%s%s%s", _("X Neural Switcher stopped ("), xconfig->handle->languages[lang].dir, ")");
+		hint = g_strdup_printf("%s%s%s", _("X Neural Switcher stopped ("), xneur_symbol, ")");
 		status_text = g_strdup_printf("%s", _("Start daemon"));
 	}
 
 	gtk_menu_item_set_label(GTK_MENU_ITEM(tray->status), status_text);
 
-	gint kbd_gr = get_active_kbd_group(dpy);
-
-
-	const char *icon_name = get_tray_icon_name(tray->images[kbd_gr]);
+	const char *icon_name = get_tray_icon_name(xneur_symbol);
 	if (tray->tray_icon)
 	{
 		gtk_widget_hide_all(GTK_WIDGET(tray->tray_icon));
 		gtk_widget_destroy (tray->image);
 		if (strcasecmp(show_in_the_tray, "Text") == 0)
 		{
-			char *layout_name = strdup(xconfig->handle->languages[kbd_gr].dir);
+			char *layout_name = get_active_kbd_symbol(dpy);
 			for (unsigned int i=0; i < strlen(layout_name); i++)
 				layout_name[i] = toupper(layout_name[i]); 
 			tray->image = gtk_label_new ((const gchar *)layout_name);
 			gtk_label_set_justify (GTK_LABEL(tray->image), GTK_JUSTIFY_CENTER);
-			free(layout_name);
+			g_free(layout_name);
 		}
 		else
 		{
-			tray->image = gtk_image_new_from_icon_name(icon_name, GTK_ICON_SIZE_LARGE_TOOLBAR);
+			if ((strcasecmp(show_in_the_tray, "Directory") != 0))
+				tray->image = gtk_image_new_from_icon_name(icon_name, GTK_ICON_SIZE_LARGE_TOOLBAR);
+			else
+				tray->image = gtk_image_new_from_file(icon_name);
 		}
 		gtk_container_add(GTK_CONTAINER(tray->evbox), tray->image);
 		gtk_widget_show_all(GTK_WIDGET(tray->tray_icon));
@@ -397,19 +430,21 @@ gboolean clock_check(gpointer dummy)
 		{					
 			if (strcasecmp(show_in_the_tray, "Text") == 0)
 			{
-				char *layout_name = strdup(xconfig->handle->languages[kbd_gr].dir);
+				char *layout_name = get_active_kbd_symbol(dpy);
 				for (unsigned int i=0; i < strlen(layout_name); i++)
 					layout_name[i] = toupper(layout_name[i]);
-
 				GdkPixbuf *pb = text_to_gtk_pixbuf (layout_name);
-				free(layout_name);
+				g_free(layout_name);
 				pb = gdk_pixbuf_add_alpha(pb, TRUE, 255, 255, 255);
 				gtk_status_icon_set_from_pixbuf(tray->status_icon, pb);
 				g_object_unref(pb);
 			}
 			else
 			{
-				gtk_status_icon_set_from_icon_name(tray->status_icon, icon_name);
+				if ((strcasecmp(show_in_the_tray, "Directory") != 0))
+					gtk_status_icon_set_from_icon_name(tray->status_icon, icon_name);
+				else
+					gtk_status_icon_set_from_file(tray->status_icon, icon_name);
 			}
 
 			gtk_status_icon_set_tooltip(tray->status_icon, hint);
@@ -418,14 +453,17 @@ gboolean clock_check(gpointer dummy)
 #ifdef HAVE_APP_INDICATOR
 	else if (tray->app_indicator)
 	{
-		char *layout_name = strdup(xconfig->handle->languages[kbd_gr].name);
 		if (strcasecmp(show_in_the_tray, "Text") == 0)
 		{
 #ifdef HAVE_DEPREC_APP_INDICATOR	
 			app_indicator_set_icon (tray->app_indicator, icon_name);
 #else
+			char *layout_name = get_active_kbd_symbol(dpy);
+			for (unsigned int i=0; i < strlen(layout_name); i++)
+				layout_name[i] = toupper(layout_name[i]);
 			app_indicator_set_label (tray->app_indicator, layout_name, layout_name);
-			app_indicator_set_icon (tray->app_indicator, "");
+			g_free(layout_name);
+			app_indicator_set_icon_full (tray->app_indicator, "", "");
 #endif
 		}
 		else
@@ -433,17 +471,16 @@ gboolean clock_check(gpointer dummy)
 #ifdef HAVE_DEPREC_APP_INDICATOR
 			app_indicator_set_icon (tray->app_indicator, icon_name);
 #else
-			app_indicator_set_icon (tray->app_indicator, icon_name);
+			app_indicator_set_icon_full (tray->app_indicator, icon_name, icon_name);
 			app_indicator_set_label (tray->app_indicator,"", "");
 #endif
 		}
-		free(layout_name);
 	}
 #endif
 
 	g_free (hint);
 	g_free (status_text);
-
+	
 	return TRUE;
 }
 
@@ -461,11 +498,11 @@ void xneur_start_stop(void)
 
 void xneur_exit(void)
 {
-	for (int i = 0; i < MAX_LAYOUTS; i++)
+	/*for (int i = 0; i < MAX_LAYOUTS; i++)
 	{
 		if (tray->images[i] != NULL)
 			g_free(tray->images[i]);
-	}
+	}*/
 
 	gtk_widget_destroy(GTK_WIDGET(tray->menu));
 	tray->menu = NULL;
@@ -502,11 +539,11 @@ void rendering_engine_callback(gpointer user_data)
 	if (strcasecmp(new_engine, rendering_engine) == 0)
 		return;
 	
-	for (int i = 0; i < MAX_LAYOUTS; i++)
+	/*for (int i = 0; i < MAX_LAYOUTS; i++)
 	{
 		if (tray->images[i] != NULL)
 			g_free(tray->images[i]);
-	}
+	}*/
 
 	gtk_widget_destroy(GTK_WIDGET(tray->menu));
 	tray->menu = NULL;
@@ -546,18 +583,18 @@ void create_tray_icon (void)
 	tray->tray_icon = NULL;
 	
 	// Init pixbuf array
-	for (int i = 0; i < MAX_LAYOUTS; i++)
+	/*for (int i = 0; i < MAX_LAYOUTS; i++)
 	{
 		tray->images[i] = NULL;
-	}
+	}*/
 
 	// Load images names
-	for (int i = 0; i < xconfig->handle->total_languages; i++)
+	/*for (int i = 0; i < xconfig->handle->total_languages; i++)
 	{
 		char *layout_name = strdup(xconfig->handle->languages[i].dir);
 		tray->images[i] = g_strdup_printf("%s-%s", PACKAGE, layout_name);
 		free(layout_name);
-	}
+	}*/
 	
 	tray->menu = create_menu(tray, xconfig->manual_mode);
 
@@ -582,17 +619,16 @@ void create_tray_icon (void)
 		}
 		else
 		{
-			tray_icon_failed = 0;
+			tray_icon_failed = 1;
 		}
 #else
 		tray_icon_failed = 1;
 #endif	
 	}
-	
-	gint kbd_gr = get_active_kbd_group(dpy);
-	
+
+
 	// Tray icon
-	if (strcasecmp(rendering_engine, "Built-in") == 0 || tray_icon_failed)
+	if (strcasecmp(rendering_engine, "Built-in") == 0 /*|| tray_icon_failed*/)
 	{
 		tray->tray_icon = _gtk_tray_icon_new(_("X Neural Switcher"));
 
@@ -605,16 +641,19 @@ void create_tray_icon (void)
 			gtk_event_box_set_visible_window(GTK_EVENT_BOX(tray->evbox), 0);
 			if (strcasecmp(show_in_the_tray, "Text") == 0)
 			{
-				char *layout_name = strdup(xconfig->handle->languages[kbd_gr].dir);
+				char *layout_name = get_active_kbd_symbol (dpy);
 				for (unsigned int i=0; i < strlen(layout_name); i++)
 					layout_name[i] = toupper(layout_name[i]); 
 				tray->image = gtk_label_new ((const gchar *)layout_name);
 				gtk_label_set_justify (GTK_LABEL(tray->image), GTK_JUSTIFY_CENTER);
-				free(layout_name);
+				g_free(layout_name);
 			}
 			else
 			{
-				tray->image = gtk_image_new_from_icon_name(tray->images[kbd_gr], GTK_ICON_SIZE_LARGE_TOOLBAR);
+				char *layout_name = get_active_kbd_symbol (dpy);
+				tray->image = gtk_image_new_from_icon_name(layout_name, GTK_ICON_SIZE_LARGE_TOOLBAR);
+				//tray->image = gtk_image_new_from_icon_name(tray->images[kbd_gr], GTK_ICON_SIZE_LARGE_TOOLBAR);
+				g_free(layout_name);
 			}
 			gtk_container_add(GTK_CONTAINER(tray->evbox), tray->image);
 			gtk_container_add(GTK_CONTAINER(tray->tray_icon), tray->evbox);
@@ -631,7 +670,7 @@ void create_tray_icon (void)
 	}
 
 	// Status Icon
-	if (!tray_icon_created)
+	if (tray_icon_failed || !tray_icon_created || strcasecmp(rendering_engine, "StatusIcon") == 0 )
 	{
 		tray->status_icon = gtk_status_icon_new();
 
@@ -644,19 +683,22 @@ void create_tray_icon (void)
 
 		if (strcasecmp(show_in_the_tray, "Text") == 0)
 		{
-			char *layout_name = strdup(xconfig->handle->languages[kbd_gr].dir);
+			char *layout_name = get_active_kbd_symbol (dpy);
 			for (unsigned int i=0; i < strlen(layout_name); i++)
 				layout_name[i] = toupper(layout_name[i]);
 
 			GdkPixbuf *pb = text_to_gtk_pixbuf (layout_name);
-			free(layout_name);
+			g_free(layout_name);
 			pb = gdk_pixbuf_add_alpha(pb, TRUE, 255, 255, 255);
 			gtk_status_icon_set_from_pixbuf(tray->status_icon, pb);
 			g_object_unref(pb);
 		}
 		else
 		{
-			gtk_status_icon_set_from_icon_name(tray->status_icon, tray->images[kbd_gr]);
+			char *layout_name = get_active_kbd_symbol (dpy);
+			//gtk_status_icon_set_from_icon_name(tray->status_icon, tray->images[kbd_gr]);
+			gtk_status_icon_set_from_icon_name(tray->status_icon, layout_name);
+			g_free(layout_name);
 		}
 	}
 	
