@@ -34,18 +34,18 @@ struct _tray_icon
 	// App Indicator part
 	AppIndicator *app_indicator;
 #endif
-	
+	 
 	// Tray part
 	GtkTrayIcon *tray_icon;
 	GtkTooltips *tooltip;
 	GtkWidget *image;
 	GtkWidget *evbox;
-	
+	 
 	// Status Icon part
 	GtkStatusIcon *status_icon;
 
 	// All
-	gchar  *images[MAX_LAYOUTS];
+	//gchar  *images[MAX_LAYOUTS];
 	GtkMenu *menu;
 	GtkWidget *status;
 	
